S3ConditionalPut

Enum S3ConditionalPut 

#[non_exhaustive]
pub enum S3ConditionalPut { ETagMatch, Disabled, }
Configure how to provide conditional put support for AmazonS3.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ETagMatch

Some S3-compatible stores, such as Cloudflare R2 and minio support conditional put using the standard HTTP precondition headers If-Match and If-None-Match

Encoded as etag ignoring whitespace



Disabled

Disable conditional put